@@ -1,5 +1,3 @@
-from typing import Optional
-
 from sqlalchemy import select
 
 from fief.models import EmailTemplate
@@ -12,6 +10,6 @@ class EmailTemplateRepository(
 ):
     model = EmailTemplate
 
-    async def get_by_type(self, type: EmailTemplateType) -> Optional[EmailTemplate]:
+    async def get_by_type(self, type: EmailTemplateType) -> EmailTemplate | None:
         statement = select(EmailTemplate).where(EmailTemplate.type == type.value)
         return await self.get_one_or_none(statement)
